function trie = build_trie_nowindow(data, feature, alphabet_size, trie_word_size)
% builds a trie for the specified feature, assuming the data has already been
% sax-ified but with NO sliding window

disp(['starting building trie for feature ', num2str(feature)]);
my_flush;

num_pos = data(1).num_pos;
num_neg = data(1).num_neg;

% build an array of all possible sequences
all_seqs = ones(alphabet_size^trie_word_size, trie_word_size);
trie(1).seq = all_seqs(1,:);
trie(1).seq_index = 1;
trie(1).pos_counts = 0;
trie(1).neg_counts = 0;

for k = 2:(alphabet_size^trie_word_size)
    next_num = get_next_num(all_seqs(k - 1,:), alphabet_size, trie_word_size);
    all_seqs(k,:) = next_num;

    % initialize the trie structure
    trie(k).seq = next_num;
    trie(k).seq_index = k;
    trie(k).pos_counts = 0;
    trie(k).neg_counts = 0;
end

% first find all the places where this sequence occurs
% loop through the positive data first
for pos = 1:num_pos
    % loop through all possible words and find their occurence in the sequence
    for w = 1:size(all_seqs,1)
        word = all_seqs(w,:);

        % my data is the current feature and trajectory we are examining
        my_data = data(pos).discrete_pos(feature).symbols;

        % find all locations of this word in the vector
        locs = find_word(my_data, word);

        if (~isempty(locs))
            %disp('found positive occurence of word')
            % store the relevant trajectory information
            trie(w).pos_counts = trie(w).pos_counts + 1;
            trie(w).pos_starts{pos} = locs;
        else
            trie(w).pos_starts{pos} = [];
        end
    end
end

% loop through the negative data next
for neg = 1:num_neg
    % loop through all possible words and find their occurence in the sequence
    for w = 1:size(all_seqs,1)
        word = all_seqs(w,:);

        % my data is the current feature and trajectory we are examining
        my_data = data(neg).discrete_neg(feature).symbols;

        % find all locations of this word in the vector
        locs = find_word(my_data, word);

        if (~isempty(locs))
            % disp('found neg occurance of word')
            % store the relevant trajectory information
            trie(w).neg_counts = trie(w).neg_counts + 1;
            trie(w).neg_starts{neg} = locs;
        else
            trie(w).neg_starts{neg} = [];
        end
    end
end


disp(['finished building trie for feature ', num2str(feature)]);
my_flush;
