% turns the pruned data into the right format for data mining

machine = 'tethys';

good_storms = load_storm_names([machine, '_storms.txt']);

num_storms = length(good_storms);
print_for_matlab = 1;

load feature_map;

%loadData is called to read in the files
pathToFiles = '/idea-scratch/weather3/';
minStormLength = 30;

% setup to save a file by storm cross sim and by sim only
storm_fid = fopen('max_mins_by_storm.csv', 'a');
sim_fid = fopen('max_mins_by_sim.csv', 'a');

names = [];
for f = 1:length(feature_map)
    names = [names, ', ', feature_map(f).name];
end

full_str = ['Storm name, Storm number, Label, Machine',  names];
if (~print_for_matlab)
  fprintf(storm_fid, '%s\n', full_str);
end

full_str = ['Storm name, Machine, Label',  names];
if (~print_for_matlab)
  fprintf(sim_fid, '%s\n', full_str);
end

% loop through all storms in this machine
for storm = 1:num_storms
    filename = [pathToFiles, good_storms(storm).name, '/savedValues2.mat'];
    if (exist(filename, 'file'))
      load(filename);
      disp(['on storm ', good_storms(storm).name]);      
    else
      disp(['skipping ', filename]);
    end

    % look at only the storms that last long enough
    newData = prune_storms(savedValues, minStormLength);

    if(size(newData,1) == 0)
      if (print_for_matlab)
        full_str = '';
      else
        full_str = sprintf('%s, %d, %s, %s, %s', ...
                           good_storms(storm).name, [], [], machine, ['no ' ...
                            'valid storms']);
      end
      
      fprintf(sim_fid, '%s\n', full_str);
      fprintf(storm_fid, '%s\n', full_str);
      continue;
    end

    labels = auto_label_storms(newData, 400, 900);
    thisStorm = zeros(length(labels), length(feature_map));
    storm_label = 0;

    % save data for the individual storms in this sim
    for l = 1:length(labels)
        idxs = find(newData(:, parms.stormIndex) == labels(l).storm_num);
        thisData = newData(idxs,:)';

        % extract the max/mins from the data from this storm
        maxMins = zeros(1,length(feature_map));
        for f = 1:length(feature_map)
            tmp = findstr(feature_map(f).name, 'max');
            if (isempty(tmp))
                maxMins(f) = min(newData(:,f));
            else
                maxMins(f) = max(newData(:,f));
            end
        end

        % save the data for all storms in this sim
        thisStorm(l, :) = maxMins;

        if (labels(l).storm_type == 0)
            label_str = 'no';
        elseif (labels(l).storm_type == 1)
            label_str = 'yes';
            storm_label = 1;
        else
            label_str = 'maybe';
            if (storm_label ~= 1)
                storm_label = 2;
            end
        end

        str = num2str(maxMins, '%f, ');
        if (print_for_matlab)
          full_str = str;
        else
          full_str = sprintf('%s, %d, %s, %s, %s', ...
                             good_storms(storm).name, labels(l).storm_num, ...
                             label_str, machine, str);
        end
        
        fprintf(storm_fid, '%s\n', full_str);
    end

    % now do the max/mins across sims
    thisData = thisStorm;

    maxMins = zeros(1,length(feature_map));
    for f = 1:length(feature_map)
        tmp = findstr(feature_map(f).name, 'max');
        if (isempty(tmp))
            maxMins(f) = min(thisData(:,f));
        else
            maxMins(f) = max(thisData(:,f));
        end
    end

    if (storm_label == 0)
        label_str = 'no';
    elseif (storm_label == 1)
        label_str = 'yes';
    else
        label_str = 'maybe';
    end
    str = num2str(maxMins, '%f, ');
    if (print_for_matlab)
      full_str = str;
    else
      full_str = sprintf('%s, %s, %s, %s', ...
                         good_storms(storm).name, machine, label_str, str);
    end
    fprintf(sim_fid, '%s\n', full_str);
end

% cleanup
fclose(storm_fid);
fclose(sim_fid);

