function create_folds(data, tries, num_folds, filePath)
% creates k-fold cross validation data and saves it to files in filepath

% first assign all the bags to folds
pos_folds = mod([1:data(1).num_pos], num_folds) + 1
neg_folds = mod([1:data(1).num_neg], num_folds) + 1

% now create a random ordering of the data to actually get different data
% into each partioning of the data
pos_storms = randperm(data(1).num_pos);
neg_storms = randperm(data(1).num_neg);

% and reorder the data accordingly
pos_folds = pos_folds(pos_storms);
neg_folds = neg_folds(neg_storms);

num_features = size(tries,2);
num_seqs = size(tries(1).trie,2);
for fold = 1:num_folds
    disp(['Creating data for fold ', num2str(fold)]);
    clear fold_data fold_tries;
    % setup the data for this fold
    pos_idxs = find(pos_folds == fold);
    neg_idxs = find(neg_folds == fold);
    clear pos_counts neg_counts;
    pos_counts = sparse(num_features, num_seqs);
    neg_counts = sparse(num_features, num_seqs);

    % there has to be a way to ditch this for loop but I can't find it
    for p = 1:length(pos_idxs)
        pos_idx = pos_idxs(p);

        % copy over the relevant data
        fold_data(p).pos = data(pos_idx).pos;
        fold_data(p).pos_name = data(pos_idx).pos_name;
        fold_data(p).discrete_pos = data(pos_idx).discrete_pos;

        for f = 1:num_features
            for s = 1:num_seqs
                fold_tries(f).trie(s).seq = tries(f).trie(s).seq;
                fold_tries(f).trie(s).seq_index = tries(f).trie(s).seq_index;
                if (~isempty(tries(f).trie(s).pos_starts{pos_idx}))
                    fold_tries(f).trie(s).pos_starts{p} = tries(f).trie(s).pos_starts{pos_idx};
                    pos_counts(f,s) = pos_counts(f,s) + 1;
                else 
                    fold_tries(f).trie(s).pos_starts{p} = [];
                end
            end
        end

    end

    % ditto on the desire to ditch the loop
    for n = 1:length(neg_idxs)
        neg_idx = neg_idxs(n);

        fold_data(n).neg = data(neg_idx).neg;
        fold_data(n).neg_name = data(neg_idx).neg_name;
        fold_data(n).discrete_neg = data(neg_idx).discrete_neg;

        for f = 1:num_features
            for s = 1:num_seqs
                if (~isempty(tries(f).trie(s).neg_starts{neg_idx}))
                    fold_tries(f).trie(s).neg_starts{n} = tries(f).trie(s).neg_starts{neg_idx};
                    neg_counts(f,s) = neg_counts(f,s) + 1;
                else
                    fold_tries(f).trie(s).neg_starts{n} = [];
                end
            end
        end

    end

    fold_data(1).num_pos = length(pos_idxs);
    fold_data(1).num_neg = length(neg_idxs);

    % setup the trie for this fold as well
    for f = 1:num_features
        for s = 1:num_seqs
            % get the unique positive counts
            fold_tries(f).trie(s).pos_counts = pos_counts(f,s);

            % get the unique negative counts
            fold_tries(f).trie(s).neg_counts = neg_counts(f,s);
        end
    end

    filename = [filePath, 'fold_', num2str(fold)];
    disp(['saving data to ', filename]);
    save(filename, 'fold_data', 'fold_tries');
end
