function rules = find_combined_rules(base_rules, grow_rules, ...
    num_pos, num_neg, pValue, maximum_rule_window)
% This function combines patterns/rules across features.  The parameters are:
% base_rules is a set of basic (single feature) rules.  They can be of any
%   length (growing them to the best length is left to a separate function).
% grow_rules is the set of rules that can be added onto base rules
% num_pos is the number of positive trajectories
% num_neg is the number of negative trajectories
% pValue is the user specified maximum allowable p-value for the rules.
%   Anything above this value is discarded.
% maximum_rule_window is the maximum distance apart that rules can appear
%   in the trajectory before they are discarded.

% checks all combinations 
num_rules = 0;
num_new_rules = 0;
rules = [];
for r1_index = 1:length(base_rules)
    r1 = base_rules(r1_index);

    % can't start at r1_index because r1 combined with r2 is different than
    % r2 combined with r1
    for r2_index = 1:length(grow_rules)
        r2 = grow_rules(r2_index);

        % tries to combine 
        combined_rule = combine_rules(r1, r2, maximum_rule_window);

        if (~isempty(combined_rule))
            % test the p-value
            table = build_contingency_table(combined_rule.trie(1), ...
                num_pos, num_neg);
            chi = calc_chisquared(table);
            p_val = 1 - chi2cdf(chi, 1);
            if (p_val < pValue)
                num_rules = num_rules + 1;
                combined_rule.chi = chi;
                combined_rule.p = p_val;
                rules = [rules, combined_rule];
            end
        end
    end
end

disp(['find combined rules returning with ', num2str(num_rules), ' rules']);