function my_rules = find_multi_rules(data, tries, min_pod, max_far, ...
    overlap_window, max_depth, single_word_rules)

% find_multi_rules continues to combine rules
% until the multi-word rules are no longer growing

% Initialize my_rules (which will become all multi_word_rules) to
% single_word rules so we have something to build from
my_rules = single_word_rules;
disp(['starting with ', num2str(size(single_word_rules,2)), ' rules']);
new_rules = my_rules;

my_rule_index = size(my_rules,2) + 1; % indexes into my_rules
rule_depth = 1;
best_csi = max([single_word_rules.csi])

while(rule_depth < max_depth)
    % Find all of the combined rules using the multi-word rules found on
    % the previous pass and all of the valid rules found so far
    new_rules = combine_rules2(data, tries, min_pod, max_far, ...
        overlap_window, new_rules, single_word_rules, best_csi);
    disp(['found ', num2str(size(new_rules,2)), ' new rules']);

    % Get the max csi from the most recently found rules
    best_csi = max([new_rules.csi])

    % If no new rules exist, there's no need to continue
    if(new_rules(1).exist == 0)
        flag = 0;
        break;
    end

    % If new rules do exist, append them to my_rules
    for idx = 1:length(new_rules)
        my_rules(my_rule_index) = new_rules(idx);
        my_rule_index = my_rule_index + 1;
    end

    % temporarily save the rules found so far for debugging purposes
    % save tornadoRulesTemp my_rules;

    rule_depth = rule_depth +1;
    disp(['my_rules now has ', num2str(size(my_rules,2)), ' rules']);
end

if(size(my_rules,2) == size(single_word_rules,2))
    my_rules(1).exist = 0;
end

disp(['Done finding new combined rules']);
