function boo = find_overlap(rule1, rule2, overlap_window)
% find_overlap is a boolean function that determines if the two rules 
% overlap in any storm. If so, then they are tested to see if they overlap 
% in the proper order (rule1 preceeding rule2 by at least a time period of 
% overlap_window). 

boo = false;

% for each storm that the first rule appears in

for t = 1:length(rule1.trie)
    tr = rule1.trie(t);

    for s = 1:length(tr.traj_index)

        % check to see if the second rule also appears in that storm
        storms = find(rule2.trie.traj_index == tr.traj_index(s));

        % for each of the storms that the rules overlap in
        for m = 1:length(storms)

            % check to see that they both occurred in either the positive
            % or negative storm
            if(tr.traj_labels(s) == rule2.trie.traj_labels(storms(m)))

                % check to make sure that rule 2 appeared after rule 1 by
                % the amount of time overlap_window
                if(length(tr.start_idxs(:,1)) == 1)
                    dif = rule2.trie.start_idxs(storms(m))- tr.start_idxs(s);
                else

                    dif = rule2.trie.start_idxs(storms(m)) - tr.start_idxs(1,s);
                end

                % Check to see if the features for rule 1 or rule 2 are
                % identical.
                if(length(rule1.features) == 1 && length(rule2.features) == 1)
                    foo = ~(rule1.features == rule2.features);
                elseif(length(rule1.features) == length(rule2.features))
                    if(length(find((rule1.features == rule2.features) == 0)) >= 1)
                        foo = 0;
                    else
                        foo = 1;
                    end
                else
                    foo = 0;
                end

                if((dif >= overlap_window || foo) && dif == 0)
                    % If we have satisfied everything, then we can set the
                    % return value to true and quit (we only need one
                    % postive case to satisfy the conditions of the method)
                    boo = true;
                    break;
                end

            end
        end
        if(boo == true)
            break;
        end
    end
end

