function rules = find_rulesPF(data, tries, min_pod, max_far)

% Find the rules that have a POD of at least min_pod and a FAR of less than
% max_far. find_rules takes the data, the
% tries built from the data, the number of negative storms, the number of
% positive storms, the minimum probability of detection (used to determine
% significance of rule), the minimum false alarm ratio (used to determine
% the significance of a rule).

% Initialize rules, which will hold all of the stat. sig. rules and
% rule_index which will keep track of the number of rules.
rule_index = 1;
epsilon = .0000000000001; % avoid divide by zero error
feat = [0];

%ignore_feats = [25, 26, 27, 44, 45, 46]; % features we do not want to build
% rules from: pressure
% perturbation and horizontal wind
% speed.

rules(rule_index).features = feat;
rules(rule_index).trie = tries(1).trie;
rules(rule_index).pod = 0;
rules(rule_index).fa_rate = 0;
rules(rule_index).fa_ratio = 0;
rules(rule_index).csi = 0;
rules(rule_index).csi_weight = 0;
%rules(rule_index).chis = 0;
%rules(rule_index).p_vals = 0;
rules(rule_index).exist = 0;

% Start by exploring all possible rules from each feature
for feature = 1:length(tries);

    %     % Do not add the ignorable features to the possible rules
    %     idxs = find(ignore_feats == feature);
    %     if(~isempty(idxs))
    %         continue;
    %     end

    trie = tries(feature).trie;

    % loop through each word in the trie for the feature
    for w = 1:length(trie)

        % Build the contingency table for this trie
        table = build_contingency_table(trie(w), data(1).num_pos, ...
            data(1).num_neg);

        % Calculate the Probability of Detection attained by the trie
        pod = table(1,1) / (table(1,1) + table(2,1) + epsilon);

        % Calculate the False Alarm Ratio attained by the trie
        fa_ratio = table(1,2) / (table(1,1) + table(1,2) + epsilon);

        % Calculate the False Alarm Rate attained by the trie
        fa_rate = table(1,2) / (table(2,2) + table(1,2) + epsilon);

        % Calculate the Critical Success Index attained by the trie
        csi = table(1,1) / (table(1,1) + table(1,2) + table(2,1) + epsilon);

        % Calculate the chi^2 value for this contingency table
        %chis = calc_chisquared(table);
        %p_vals = 1 - chi2pdf(chis, ones(1, length(chis)));

        % if pod>min_pod and if far<max_far then we want to add the word to
        % our list of rules
        if (pod > min_pod && fa_ratio < max_far)
            disp(['The rule has POD ', num2str(pod), ' and FA Ratio ', num2str(fa_ratio)]);
            feat = [feat; feature];
            feat(1,:) = [];
            rules(rule_index).features = feat;
            rules(rule_index).trie = trie(w);
            rules(rule_index).pod = pod;
            rules(rule_index).fa_rate = fa_rate;
            rules(rule_index).fa_ratio = fa_ratio;
            rules(rule_index).csi = csi;
            rules(rule_index).csi_weight = 0;
            %rules(rule_index).chis = chis;
            %rules(rule_index).p_vals = p_vals;
            rules(rule_index).exist = 1;
            rule_index = rule_index + 1;
        end

    end

end


