function rules = find_valid_rules(data, tries, min_pod, max_far, overlap_window, depth)

% This function finds all of the valid rules from the storms (both single
% word and multi-word) and concatenates them into a struct called rules.
% Valid rules are determined by their POD and FAR and whether or not they
% "legally" overlap

idx = 1;

rules(idx).features = 0;
rules(idx).trie = tries(1).trie;
rules(idx).pod = 0;
rules(idx).fa_rate = 0;
rules(idx).fa_ratio = 0;
rules(idx).csi = 0;
rules(idx).csi_weight = 0;
%rules(idx).chis = 0;
%rules(idx).p_vals = 0;
rules(idx).exist = 0;

% run the single-word rule-finding algorithm
single_word_rules = find_rules_PF(data, tries, min_pod, max_far);

% only if single-word rules exist do we need to do anything
if(single_word_rules(1).exist ~= 0)
    % Add all of the single-word rules to the rules struct
    for i = 1:length(single_word_rules)
        rules(idx) = single_word_rules(i);
        idx = idx + 1;
    end

    disp(['We found ', num2str(length(rules)), ' single-word rules with POD > ', ...
        num2str(min_pod), ' and FAR < ', num2str(max_far)]);

    % We have single word rules to work with, so try to find multi-word
    % rules
    multi_word_rules = find_multi_rules(data, tries, min_pod, max_far, ...
        overlap_window, depth, single_word_rules);

    % Only if multi-word rules exist do we need to add them to the rules
    % struct
    if(multi_word_rules(1).exist ~=0)
        for i = 1:length(multi_word_rules)
            rules(idx) = multi_word_rules(i);
            idx = idx+1;
        end
    end

else
    disp(['We found no single-word rules with POD: ', ...
        num2str(min_pod), ' and FAR: ', num2str(max_far)]);
end

% sort the rules by csi
csis = [rules.csi];
[vals, idxs] = sort(csis, 'descend');

sorted_rules = rules(idxs);
rules = sorted_rules;
