function locations = find_word(vector, word)
% finds all locations of the given word in the vector

% find all the places where the word may start
idxs = find(vector == word(1));

% if the first number isn't even there, return right away
if (isempty(idxs))
    locations = [];
    return;
end

% the first letter is there, so examine the remaining possibilities by 
% building a matrix of possible words.  We have to do it this way because
% ismember only considers sets to be ordered if they are in matrix
% format and not in vector format
word_size = length(word);
vector_size = length(vector);
valid_data = 0;

for row = 1:length(idxs)
    start_index = idxs(row);
    last_index = (idxs(row) + word_size - 1);
    if (last_index <= vector_size)
        data(row,:) = vector(start_index:last_index);
        valid_data = 1;
    end
end

if (~valid_data)
    locations = [];
    return;
end

% now see if any of the rows match
[tf, locs] = ismember(data, word, 'rows');

% did we find anything?
if (isempty(locs))
    locations = [];
    return;
end

% if so, then save the locations
locations = idxs(find(locs));
