function [best, used_idxs] = get_best_rule(data, valid_rules, storm_weights, used_idxs)

% get_best_rule determines the best rule out of all rules based on critical success index of each rule. 
% The contingency table of each rule is recalculated based on the weights of each storm. Also, get_best_rule
% keeps track of the best rules seen so far in the used_idxs vector in order to guarantee that each time 
% we are returning a unique best rule. 

num_pos = data(1).num_pos;
num_neg = data(1).num_neg;
num_features = data(1).num_features;
best = valid_rules(1);
best_idx = 1;

num_pos_weight = 0;
num_neg_weight = 0;
pos_counts = 0;
neg_counts = 0;
flag = 0;

epsilon = 0.000000000000001;

% Count up the weight totals for the positive and negative storms
for s = 1:(num_pos+num_neg)
    if(s <= num_pos)
        num_pos_weight = num_pos_weight + storm_weights(s);
    else 
        num_neg_weight = num_neg_weight + storm_weights(s);
    end
end

for idx = 1:length(valid_rules)
    rule = valid_rules(idx);
    for storm = 1:(num_pos + num_neg)
        for feature = 1:num_features
            if ((all(find(feature == rule.features),2)))
                % if the storm is positive, get the discrete positive data for
                % the storm, if it's negative, get the discrete negative data.
                % Store the symbols for the feature trajectory in my_data
                if(storm <= num_pos)
                    my_data = data(storm).discrete_pos(feature).symbols;
                else
                    my_data = data(storm-num_pos).discrete_neg(feature).symbols;
                end

                % find all locations of the best rule's word in the vector
                locs = find_word(my_data, rule.trie.seq);

                % if the word occurs in the storm then we want to add that to the 
                % positive or negative counts 
                if (~isempty(locs))
                    flag = 1; % assign the flag to true indicating we found an occuracnce of the rule
                    break; % we can break once we've found a single positive instance
                end
            end
        
            % If the rule seq appeared in the storm, add the wieghts for that
            % storm to the pos_counts or neg_counts depending on whether the
            % storm was positive or negative 
            if(flag)
               if(storm <= num_pos)
                  pos_counts = pos_counts + storm_weights(storm);
               else
                  neg_counts = neg_counts + storm_weights(storm);
               end

            end
            flag = 0;
         end
     end
    
    % build the contingency table for the rule based on the weighted
    % counts
    table(1,1) = pos_counts;
    table(1,2) = neg_counts;
    table(2,1) = num_pos_weight - pos_counts;
    table(2,2) = num_neg_weight - neg_counts;
    
    rule.csi_weight = table(1,1) / (table(1,1) + table(1,2) + table(2,1) + epsilon);

% If we have found a better rule than the one we previously had, then re-assign
% best and best_idx
    if(rule.csi_weight > best.csi_weight && (isempty(find(idx == used_idxs))))
        best = rule;
	best_idx = idx;
    end

	pos_counts = 0;
        neg_counts = 0;

end

% Add the idx of the best rule found to the used_idxs
used_idxs = [used_idxs, best_idx];
