function data_windows = identify_data_window(savedValues, window_size, pp_yes_drop)
% identifies the window for positive data where the approach first looks for the
% timestamp of the pressure drop and then finds the gradient to find the place
% where it drops precipitiously
% NOTE: this function assumes that the savedValues array has already been
% narrowed down to a single storm AND that it is positive (e.g. has a pressure
% drop worth noting)

pp_surface = savedValues(27,:);
len = length(pp_surface);

% run a subtraction over the window to find the drops that fit our criteria
% and particularly to find the left index of them
pp_surface_yes = zeros(1,len);
for sz = 2:33
    vec = zeros(1,sz);
    vec(1) = 1;
    vec(sz) = -1;

    diffs_surf = conv(vec, pp_surface);

    % chop off the ends (invalid data)
    diffs_surf = diffs_surf(sz:len);

    % readjust to line up with the real data
    diffs_surf2 = [zeros(1,sz - 1), diffs_surf];

    % now see if the correct drop exists anywhere in the convolution
    yes_idxs = find(diffs_surf2 <= -pp_yes_drop);
    
    idxs = max(yes_idxs - sz - 1, 1);
    
    pp_surface_yes(idxs) = 1;
    
    if (~isempty(idxs))
        break
    end
end

% create a gaussian derivative function to find the places that the
% pressure drops dramatically
% all_mins = zeros(1,len);
% 
% for gauss_size = 11:4:66
%     gaus = gauswavf(-4, 4, gauss_size, 1);
% 
%     % convolve it over the image
%     cdata = conv(gaus, pp_surface);
% 
%     % chop off the ends (invalid data)
%     cdata = cdata(gauss_size:length(pp_surface));
%     
%     if (length(cdata)/length(pp_surface) < 0.8)
%          break;
%     end
%     
%     % plot the convolution (to keep me from being too confused!)
%     cdata2 = [zeros(gauss_size-1,1); cdata];
%     
%     % normalize
%     cdata2 = cdata2 / std(cdata2);
% 
%     % now try to reconstruct where it occurred in the real data
%     idxs = find(cdata2 < -2);
% 
%     all_mins(idxs - gauss_size) = 1;
% end

% now do the and of those two:  where it drops AND where it drops for our
% defined threshold
% to account for noise, also blur each a little bit
% se = strel('disk', 4);
% pp2 = imdilate(pp_surface_yes, se);
% mins2 = imdilate(all_mins, se);

% combined_drops = pp2 & mins2;
combined_drops = pp_surface_yes;

% now that we have the drops identified, go back and find the starting
% point of each drop.  the first step is to identify the number of drops
drops = bwlabel(combined_drops);
num_drops = max(drops);
for drop = 1:num_drops
   drop_idxs = find(drops == drop);
   storm_start(drop) = min(drop_idxs);
end

% now that we have the set of storm starts, only save those with at least 30
% minutes of history backwards in time. this means the storm starts need to be
% at least 30 minutes apart as well.  prefer the earliest start first.
sorted_starts = sort(storm_start);
windows = zeros(1,len);

% for debugging, plot the window
hold off
plot(pp_surface)
hold on

% loop variables
data_windows(1).start_idx = 0;
data_windows(1).end_idx = 0;
num_windows = 1;

colors = ['r', 'g', 'k', 'c', 'm', 'y'];

% look through each potential start
for start = 1:length(sorted_starts)
    start_idx = max(1,sorted_starts(start) - (2*window_size) + 1);
    if (sorted_starts(start) - (2*window_size) + 1 < 0)
        disp('toss storm as it is too short?');
    end
    
    end_idx = max(sorted_starts(start), start_idx + (2 * window_size) - 1);
    if (sum(windows(start_idx:end_idx)) < 1)
        windows(start_idx:end_idx) = 1;
        % now plot the windows
        h = plot(start_idx:end_idx, pp_surface(start_idx:end_idx));
        set(h, 'LineWidth', 2, 'Color', colors(mod(start, length(colors))));
        data_windows(num_windows).start_idx = start_idx;
        data_windows(num_windows).end_idx = end_idx;
        num_windows = num_windows + 1;
    end
end

