function [valid, rule] = is_valid_rule2(rule1, rule2, min_pod, max_far, ...
    num_pos, num_neg, overlap_window)
% Determines if rule1 and rule2 concatenated is a rule that satisfies the
% POD-FARatio requirement. If so, then valid is set to true and the rule is
% set to the valid rule with all rule information. If not, then valid is set
% to false, and rule is left undeclared.

epsilon = .0000000000001; % avoid divide by zero error

% maximum overlap is 10 minutes - FIX this to not be hard-coded
maximum_overlap = 10;

% loop through each storm and see if this combination appears within the
% valid amount of overlap
num_features = size(rule1.features,1);
new_rule.features = [rule1.features; rule2.features];
new_trie.seq = [rule1.trie.seq; rule2.trie.seq];
new_trie.seq_index = [rule1.trie.seq_index; rule2.trie.seq_index];
pos_counts = 0;
neg_counts = 0;

for p = 1:num_pos
    % get the starting times for the last feature in rule 1
    if (num_features > 1)
        last_starts = rule1.trie.pos_starts{p,num_features};
    else
        last_starts = rule1.trie.pos_starts{p};
    end

    % if the starting times are not empty, get the times for rule 2
    valid_starts = [];
    if (~isempty(last_starts))
        starts2 = rule2.trie.pos_starts{p};

        % run through the two starting times and save the valid ones
        for s = 1:length(last_starts)
            diffs = starts2 - last_starts(s);
            if (rule1.features(num_features) == rule2.features)
                seq_length = size(rule1.trie.seq,2);
                idxs = find(diffs >= (overlap_window + seq_length - 1) & diffs <= maximum_overlap);
            else
                idxs = find(diffs >= overlap_window & diffs <= maximum_overlap);
            end
            valid_starts = [valid_starts, starts2(idxs)];
        end
        valid_starts = unique(valid_starts);
    end
    for f = 1:num_features
        if (num_features > 1)
            new_trie.pos_starts{p,f} = rule1.trie.pos_starts{p,f};
        else
            new_trie.pos_starts{p,f} = rule1.trie.pos_starts{p};
        end
    end
    new_trie.pos_starts{p,num_features + 1} = valid_starts;

    % if we had a non-empty valid starts, then update the positive counts
    if (~isempty(valid_starts))
        pos_counts = pos_counts + 1;
    end
end

for p = 1:num_neg
    % get the starting times for the last feature in rule 1
    if (num_features > 1)
        last_starts = rule1.trie.neg_starts{p,num_features};
    else
        last_starts = rule1.trie.neg_starts{p};
    end

    % if the starting times are not empty, get the times for rule 2
    valid_starts = [];
    if (~isempty(last_starts))
        starts2 = rule2.trie.neg_starts{p};

        % run through the two starting times and save the valid ones
        for s = 1:length(last_starts)
            diffs = starts2 - last_starts(s);
            if (rule1.features(num_features) == rule2.features)
                seq_length = size(rule1.trie.seq,2);
                idxs = find(diffs >= (overlap_window + seq_length - 1) & diffs <= maximum_overlap);
            else
                idxs = find(diffs >= overlap_window & diffs <= maximum_overlap);
            end
            valid_starts = [valid_starts, starts2(idxs)];
        end
        valid_starts = unique(valid_starts);
    end
    
    % save the starts in an array of size <num_neg, num_features>
    for f = 1:num_features
        if (num_features > 1)
            new_trie.neg_starts{p,f} = rule1.trie.neg_starts{p,f};
        else
            new_trie.neg_starts{p,f} = rule1.trie.neg_starts{p};
        end
    end
    new_trie.neg_starts{p,num_features + 1} = valid_starts;

    % if we had a non-empty valid starts, then update the negative counts
    if (~isempty(valid_starts))
        neg_counts = neg_counts + 1;
    end

end

% update the unique positive and negative counts
new_trie.pos_counts = pos_counts;
new_trie.neg_counts = neg_counts;

% Build the contingency table for this trie
table = build_contingency_table(new_trie, num_pos, num_neg);

% Calculate the Probability of Detection attained by the trie
pod = table(1,1) / (table(1,1) + table(2,1) + epsilon);

% Calculate the False Alarm Ratio attained by the trie
fa_ratio = table(1,2) / (table(1,1) + table(1,2) + epsilon);

% Calculate the False Alarm Rate attained by the trie
fa_rate = table(1,2) / (table(2,2) + table(1,2) + epsilon);

% Calculate the Critical Success Index attained by the trie
csi = table(1,1) / (table(1,1) + table(1,2) + table(2,1) + epsilon); 

% save the output arguments
rule = new_rule;
rule.trie = new_trie;

% if pod>min_pod and if far<max_far then we want to add the word to
% our list of rules
if (pod > min_pod && fa_ratio < max_far)
    rule.pod = pod;
    rule.fa_rate = fa_rate;
    rule.fa_ratio = fa_ratio;
    rule.csi = csi;
    rule.csi_weight = 0;
    rule.exist = 1;

    valid = true;
else
    valid = false;
end



