function [train_data, train_tries, test_data, test_tries] = ...
    load_fold(test_fold, num_folds, filePath)

disp(['test fold is ', num2str(test_fold)]);

train_data = [];
train_tries = [];
test_data = [];
test_tries = [];

% loads in the fold data from the files and combines it for the folds
for fold = 1:num_folds
    disp(['Merging data from fold ', num2str(fold)]);
    filename = [filePath, 'fold_', num2str(fold)];
    load(filename);

    if (fold == test_fold)
        disp(['On test fold ', num2str(fold)]);
        % if this is the test fold, just save the data
        test_data = fold_data;
        test_tries = fold_tries;
    else
        % it is a training fold so we need to combine the data
        if (length(train_data) == 0)
            % if we haven't created the training data yet, just save this
            % round
            train_data = fold_data;
            train_tries = fold_tries;
        else
            num_features = size(train_tries,2);
            num_seqs = size(train_tries(1).trie,2);

            % merge the data with the existing train_data structure
            idx = train_data(1).num_pos;
            for p = 1:(fold_data(1).num_pos)
                train_data(p + idx).pos = fold_data(p).pos;
                train_data(p + idx).pos_name = fold_data(p).pos_name;
                train_data(p + idx).discrete_pos = fold_data(p).discrete_pos;

                % merge the tries
                for f = 1:num_features
                    for s = 1:num_seqs
                        train_tries(f).trie(s).pos_starts{p+idx} = ...
                            fold_tries(f).trie(s).pos_starts{p};
                    end
                end
            end
            train_data(1).num_pos = train_data(1).num_pos + fold_data(1).num_pos;

            idx = train_data(1).num_neg;
            for p = 1:(fold_data(1).num_neg)
                train_data(p + idx).neg = fold_data(p).neg;
                train_data(p + idx).neg_name = fold_data(p).neg_name;
                train_data(p + idx).discrete_neg = fold_data(p).discrete_neg;
                
                 % merge the tries
                for f = 1:num_features
                    for s = 1:num_seqs
                        train_tries(f).trie(s).neg_starts{p+idx} = ...
                            fold_tries(f).trie(s).neg_starts{p};
                    end
                end
            end
            train_data(1).num_neg = train_data(1).num_neg + fold_data(1).num_neg;
        end
    end
end

disp('updating positive/negative counts');
% update the unique positive and negative counts
for f = 1:num_features
    for s = 1:num_seqs

        % get the unique positive counts
        pos_counts = 0;
        for p = 1:size(train_tries(f).trie(s).pos_starts,2)
           if (~isempty(train_tries(f).trie(s).pos_starts{p}))
            pos_counts = pos_counts + 1;
           end
        end
        train_tries(f).trie(s).pos_counts = pos_counts;
        
        % get the unique negative counts
        neg_counts = 0;
        for n = 1:size(train_tries(f).trie(s).neg_starts,2)
           if (~isempty(train_tries(f).trie(s).neg_starts{n}))
               neg_counts = neg_counts + 1;
           end
        end
        train_tries(f).trie(s).neg_counts = neg_counts;
    end
end

