alphabet_sizes = [3:8];
trie_word_sizes = [2:3];
averaging_intervals = [1:5];

fid = fopen('mining_parms.csv', 'w');
dirname = '/idea/mining_mocap/subject16/';

str = ['Alphabet size, Trie word size, Averaging interval, ', ...
       'Training pod, Training far, Training csi, Test pod, ', ...
       'Test far, Test csi, Num folds completed'];
fprintf(fid, '%s\n', str);

for alpha_idx = 1:length(alphabet_sizes)
  for trie_idx = 1:length(trie_word_sizes)
    for avg_idx = 1:length(averaging_intervals)
      filename = [dirname, 'results_let', num2str(alphabet_sizes(alpha_idx)), ...
                  '_word', num2str(trie_word_sizes(trie_idx)), ...
                  '_avg', num2str(averaging_intervals(avg_idx)), ...
                  '.mat'];
      % open it if it exists!
      if (exist(filename, 'file'))
        load(filename);
        
        avg_train_pod = mean(train_pod);
        avg_train_far = mean(train_far);
        avg_train_csi = mean(train_csi);

        avg_test_pod = mean(test_pod);
        avg_test_far = mean(test_far);
        avg_test_csi = mean(test_csi);
        
        all_results(alphabet_sizes(alpha_idx), ...
            trie_word_sizes(trie_idx), averaging_intervals(avg_idx)) = ...
            avg_test_csi;
        alpha_nums(alphabet_sizes(alpha_idx), ...
            trie_word_sizes(trie_idx), averaging_intervals(avg_idx)) = ...
            alphabet_sizes(alpha_idx);
        trie_nums(alphabet_sizes(alpha_idx), ...
            trie_word_sizes(trie_idx), averaging_intervals(avg_idx)) = ...
            trie_word_sizes(trie_idx);
        avg_nums(alphabet_sizes(alpha_idx), ...
            trie_word_sizes(trie_idx), averaging_intervals(avg_idx)) = ...
            averaging_intervals(avg_idx);
        

        fprintf(fid, '%d, %d, %d, %f, %f, %f, %f, %f, %f, %d\n', ...
                alphabet_sizes(alpha_idx), trie_word_sizes(trie_idx), ...
                averaging_intervals(avg_idx), ...
                avg_train_pod, avg_train_far, avg_train_csi, ...
                avg_test_pod, avg_test_far, avg_test_csi, length(test_pod));
      end
    end
  end
end

  
fclose(fid);

figure(1)
idxs = find(alpha_nums);
plot(alpha_nums(idxs), all_results(idxs), '.')
title('Number of letters in the alphabet')
ylabel('Test CSI');

figure(2)
plot(trie_nums(:), all_results(:), '.')
title('Number of letters in the word')
ylabel('Test CSI');

figure(3)
plot(avg_nums(:), all_results(:), '.')
title('Number of 30 second intervals averaged over')
ylabel('Test CSI');

figure(4)
idxs2 = find(trie_nums == 2);
idxs3 = find(trie_nums == 3);
idxs5 = find(trie_nums == 5);
hold off
plot(alpha_nums(idxs2), all_results(idxs2), 'r.')
hold on
plot(alpha_nums(idxs3), all_results(idxs3), 'b.')
plot(alpha_nums(idxs5), all_results(idxs5), 'g.')
xlabel('Alphabet size')
ylabel('Test CSI')
legend('Word size 2', 'Word size 3', 'Word Size 5');

figure(5)
idxs1 = find(avg_nums == 1);
idxs2 = find(avg_nums == 2);
idxs3 = find(avg_nums == 3);
idxs4 = find(avg_nums == 4);
idxs5 = find(avg_nums == 5);
hold off
plot(alpha_nums(idxs1), all_results(idxs1), 'r.')
hold on
plot(alpha_nums(idxs2), all_results(idxs2), 'b.')
plot(alpha_nums(idxs3), all_results(idxs3), 'g.')
plot(alpha_nums(idxs4), all_results(idxs4), 'k.')
plot(alpha_nums(idxs5), all_results(idxs5), 'm.')
xlabel('Alphabet size')
ylabel('Test CSI')
legend('Avg 1', 'Avg 2', 'Avg 3', 'Avg 4', 'Avg 5');

