function plot_discrete_rule(rule, rule_idx)
global feature_map;

% Plot discrete rule takes the index of the storm onto which the rule is to be
% plotted and the rule to be plotted and plots each feature of the rule as
% a separate subplot and each occurence of the rule in each feature.

% Check to make sure this rule shows up in the given storm
feats = rule.features;

color = {'g', 'y', 'm', 'c', 'p', 'r'};
symbols = {'a', 'b', 'c', 'd', 'e', 'f'};

for f = 1:length(feats)
    % extract the feature mean and standard deviation
    feat_mean = feature_map(feats(f)).mean;
    feat_std = feature_map(feats(f)).std;

    % Plot the guidelines for the normalization  for each feature
    cutlines  = [feat_mean-(2*feat_std) feat_mean-feat_std  feat_mean ...
        feat_mean+feat_std feat_mean+(2*feat_std)]; % specific for a 6 letter alphabet

    subplot(length(feats), 1, f, 'align');
    set(gcf, 'Position', [0 0 1024 1024]);
    set(gcf, 'PaperPositionMode', 'auto');

    guidelines = repmat(cutlines', 1, 10);
    h = plot(guidelines', 'color', [0.8 0.8 0.8]);
    hold on;

    % Get the sequence for this feature
    seq = rule.trie.seq(f,:);

    % Draw the segment and the symbol
    seg = map_to_values(seq, symbols, cutlines, feat_std);
    x_start = 1;
    x_end = 3;
    x_mid = 2;

    for s = 1:length(seg)
        plot([x_start:x_end], ones(1,3)*seg(s), 'color', color{seq(s)},  'linewidth', 4);
        text(x_mid, seg(s), symbols{seq(s)}, 'fontsize', 24);
        x_start = x_end + 1;
        x_end = x_end + 3;
        x_mid = x_start + (x_end - x_start)/2;
    end

    if(f == 1)
        title({['Rule ', num2str(rule_idx)]; [' has POD ', num2str(rule.pod), ...
            ' FAR (ratio) of ', num2str(rule.fa_ratio), ' and CSI of ', ...
            num2str(rule.csi)]; ['Feature: ', feature_map(feats(f)).name]});
    else
        title(['Feature: ', feature_map(feats(f)).name]);
    end
    label_axes(feats(f));
end

Save figure
fileName = ['rules_noPP_noHWS/', 'rule_', num2str(rule_idx), '.eps'];
print('-depsc ', fileName);
close;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  LOCAL FUNCTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function seg = map_to_values(seq, symbols, cutlines, feat_std)
seg = [];

for s = 1:length(seq)
    switch seq(s)
        case 1, val = (cutlines(1) - feat_std);
        case 2, val = (cutlines(1) + cutlines(2)) / 2;
        case 3, val = (cutlines(2) + cutlines(3)) / 2;
        case 4, val = (cutlines(3) + cutlines(4)) / 2;
        case 5, val = (cutlines(4) + cutlines(5)) / 2;
        case 6, val = (cutlines(5) + feat_std);
        otherwise, disp('WARNING');
    end
    seg = [seg val];
end


function label_axes(idx)
if((idx >= 1 && idx <= 6) || (idx >=44 && idx <= 46))
    ylabel('m s^{-1}');
elseif((idx >= 7 && idx <= 14) || (idx >= 32 && idx <= 35) || (idx >= 44 && idx == 58))
    ylabel('s^{-1}');
elseif((idx == 15 || idx == 16) || (idx ==36  || idx == 37))
    ylabel('kg kg^{-1}');
elseif((idx >= 17 && idx <= 22) || (idx >= 38  || idx <= 43))
    ylabel('kg kg^{-1} m^{-1}');
elseif(idx == 23 || idx == 24)
    ylabel('K');
elseif(idx == 21 || idx == 22 || idx == 23)
    ylabel('Pascal');
elseif(idx >= 25 && idx <= 27)
    ylabel('m s^{-2}');
elseif(idx == 66 || idx == 67)
    ylabel('K m^{-1}');
elseif(idx == 68 || idx == 69)
    ylabel('dBZ');
elseif(idx >= 70 && idx <= 75)
    ylabel('dBZ m^{-1}');
end
